# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: define.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='define.proto',
  package='dataset_proto',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0c\x64\x65\x66ine.proto\x12\rdataset_proto\"\x94\x02\n\x07\x46\x65\x61ture\x12\x16\n\x0cstring_field\x18\x02 \x01(\tH\x00\x12\x15\n\x0b\x62ytes_field\x18\x03 \x01(\x0cH\x00\x12\x17\n\rfloat64_field\x18\x04 \x01(\x01H\x00\x12\x15\n\x0bint64_field\x18\x05 \x01(\x03H\x00\x12\x38\n\x12\x66\x65\x61ture_list_field\x18\x07 \x01(\x0b\x32\x1a.dataset_proto.FeatureListH\x00\x12\x36\n\x11\x66\x65\x61ture_map_field\x18\x08 \x01(\x0b\x32\x19.dataset_proto.FeatureMapH\x00\x12\x30\n\nfile_field\x18\t \x01(\x0b\x32\x1a.dataset_proto.FileContentH\x00\x42\x06\n\x04kind\"\x98\x01\n\x0b\x46ileContent\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.dataset_proto.FileContent.FileType\x12\x13\n\x0b\x62ytes_field\x18\x02 \x01(\x0c\x12\x11\n\tfile_path\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x03\" \n\x08\x46ileType\x12\t\n\x05small\x10\x00\x12\t\n\x05large\x10\x01\"\x81\x01\n\nFeatureMap\x12/\n\x03map\x18\x01 \x03(\x0b\x32\".dataset_proto.FeatureMap.MapEntry\x1a\x42\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.dataset_proto.Feature:\x02\x38\x01\"3\n\x0b\x46\x65\x61tureList\x12$\n\x04list\x18\x01 \x03(\x0b\x32\x16.dataset_proto.Feature\"\x16\n\x05Index\x12\r\n\x05index\x18\x01 \x03(\x03\"S\n\x04Meta\x12\x0f\n\x07version\x18\x01 \x01(\x03\x12\n\n\x02id\x18\x02 \x01(\t\x12.\n\x0brecord_type\x18\x03 \x01(\x0b\x32\x19.dataset_proto.RecordType\"\xed\x02\n\nRecordType\x12\x36\n\tbasicType\x18\x01 \x01(\x0e\x32#.dataset_proto.RecordType.BasicType\x12=\n\nproperties\x18\x02 \x03(\x0b\x32).dataset_proto.RecordType.PropertiesEntry\x12\x0c\n\x04keys\x18\x03 \x03(\t\x12\'\n\x04item\x18\x04 \x01(\x0b\x32\x19.dataset_proto.RecordType\x1aL\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.dataset_proto.RecordType:\x02\x38\x01\"c\n\tBasicType\x12\n\n\x06unKnow\x10\x00\x12\t\n\x05\x62ytes\x10\x01\x12\x0b\n\x07\x66loat64\x10\x02\x12\t\n\x05int64\x10\x03\x12\x08\n\x04list\x10\x04\x12\x07\n\x03map\x10\x05\x12\n\n\x06string\x10\x06\x12\x08\n\x04\x66ile\x10\x07\"\x81\x01\n\x08Property\x12-\n\x03map\x18\x01 \x03(\x0b\x32 .dataset_proto.Property.MapEntry\x1a\x46\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.dataset_proto.DynamicType:\x02\x38\x01\"\x95\x03\n\x0b\x44ynamicType\x12\x31\n\x04\x66lag\x18\x01 \x01(\x0e\x32#.dataset_proto.DynamicType.TypeFlag\x12\x0e\n\x06string\x18\x02 \x01(\t\x12\r\n\x05\x62ytes\x18\x03 \x01(\x0c\x12\x0f\n\x07\x66loat64\x18\x04 \x01(\x01\x12\r\n\x05int64\x18\x05 \x01(\x03\x12(\n\x04list\x18\x06 \x03(\x0b\x32\x1a.dataset_proto.DynamicType\x12\x30\n\x03map\x18\x07 \x03(\x0b\x32#.dataset_proto.DynamicType.MapEntry\x1a\x46\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.dataset_proto.DynamicType:\x02\x38\x01\"p\n\x08TypeFlag\x12\x10\n\x0cstring_field\x10\x00\x12\x0f\n\x0b\x62ytes_field\x10\x01\x12\x11\n\rfloat64_field\x10\x02\x12\x0f\n\x0bint64_field\x10\x03\x12\x0e\n\nlist_field\x10\x04\x12\r\n\tmap_field\x10\x05\x62\x06proto3')
)



_FILECONTENT_FILETYPE = _descriptor.EnumDescriptor(
  name='FileType',
  full_name='dataset_proto.FileContent.FileType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='small', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='large', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=431,
  serialized_end=463,
)
_sym_db.RegisterEnumDescriptor(_FILECONTENT_FILETYPE)

_RECORDTYPE_BASICTYPE = _descriptor.EnumDescriptor(
  name='BasicType',
  full_name='dataset_proto.RecordType.BasicType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unKnow', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='bytes', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='float64', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='int64', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='list', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='map', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='string', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='file', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1026,
  serialized_end=1125,
)
_sym_db.RegisterEnumDescriptor(_RECORDTYPE_BASICTYPE)

_DYNAMICTYPE_TYPEFLAG = _descriptor.EnumDescriptor(
  name='TypeFlag',
  full_name='dataset_proto.DynamicType.TypeFlag',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='string_field', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='bytes_field', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='float64_field', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='int64_field', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='list_field', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='map_field', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1553,
  serialized_end=1665,
)
_sym_db.RegisterEnumDescriptor(_DYNAMICTYPE_TYPEFLAG)


_FEATURE = _descriptor.Descriptor(
  name='Feature',
  full_name='dataset_proto.Feature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_field', full_name='dataset_proto.Feature.string_field', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_field', full_name='dataset_proto.Feature.bytes_field', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float64_field', full_name='dataset_proto.Feature.float64_field', index=2,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int64_field', full_name='dataset_proto.Feature.int64_field', index=3,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feature_list_field', full_name='dataset_proto.Feature.feature_list_field', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feature_map_field', full_name='dataset_proto.Feature.feature_map_field', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_field', full_name='dataset_proto.Feature.file_field', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='dataset_proto.Feature.kind',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=32,
  serialized_end=308,
)


_FILECONTENT = _descriptor.Descriptor(
  name='FileContent',
  full_name='dataset_proto.FileContent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dataset_proto.FileContent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_field', full_name='dataset_proto.FileContent.bytes_field', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_path', full_name='dataset_proto.FileContent.file_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='dataset_proto.FileContent.size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FILECONTENT_FILETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=463,
)


_FEATUREMAP_MAPENTRY = _descriptor.Descriptor(
  name='MapEntry',
  full_name='dataset_proto.FeatureMap.MapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataset_proto.FeatureMap.MapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataset_proto.FeatureMap.MapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=595,
)

_FEATUREMAP = _descriptor.Descriptor(
  name='FeatureMap',
  full_name='dataset_proto.FeatureMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map', full_name='dataset_proto.FeatureMap.map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FEATUREMAP_MAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=595,
)


_FEATURELIST = _descriptor.Descriptor(
  name='FeatureList',
  full_name='dataset_proto.FeatureList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list', full_name='dataset_proto.FeatureList.list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=597,
  serialized_end=648,
)


_INDEX = _descriptor.Descriptor(
  name='Index',
  full_name='dataset_proto.Index',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='dataset_proto.Index.index', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=650,
  serialized_end=672,
)


_META = _descriptor.Descriptor(
  name='Meta',
  full_name='dataset_proto.Meta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='dataset_proto.Meta.version', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='dataset_proto.Meta.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='record_type', full_name='dataset_proto.Meta.record_type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=757,
)


_RECORDTYPE_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='dataset_proto.RecordType.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataset_proto.RecordType.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataset_proto.RecordType.PropertiesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=1024,
)

_RECORDTYPE = _descriptor.Descriptor(
  name='RecordType',
  full_name='dataset_proto.RecordType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='basicType', full_name='dataset_proto.RecordType.basicType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='dataset_proto.RecordType.properties', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keys', full_name='dataset_proto.RecordType.keys', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item', full_name='dataset_proto.RecordType.item', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RECORDTYPE_PROPERTIESENTRY, ],
  enum_types=[
    _RECORDTYPE_BASICTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=760,
  serialized_end=1125,
)


_PROPERTY_MAPENTRY = _descriptor.Descriptor(
  name='MapEntry',
  full_name='dataset_proto.Property.MapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataset_proto.Property.MapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataset_proto.Property.MapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1187,
  serialized_end=1257,
)

_PROPERTY = _descriptor.Descriptor(
  name='Property',
  full_name='dataset_proto.Property',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map', full_name='dataset_proto.Property.map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PROPERTY_MAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1128,
  serialized_end=1257,
)


_DYNAMICTYPE_MAPENTRY = _descriptor.Descriptor(
  name='MapEntry',
  full_name='dataset_proto.DynamicType.MapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dataset_proto.DynamicType.MapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dataset_proto.DynamicType.MapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1187,
  serialized_end=1257,
)

_DYNAMICTYPE = _descriptor.Descriptor(
  name='DynamicType',
  full_name='dataset_proto.DynamicType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flag', full_name='dataset_proto.DynamicType.flag', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string', full_name='dataset_proto.DynamicType.string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='dataset_proto.DynamicType.bytes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float64', full_name='dataset_proto.DynamicType.float64', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int64', full_name='dataset_proto.DynamicType.int64', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list', full_name='dataset_proto.DynamicType.list', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='map', full_name='dataset_proto.DynamicType.map', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DYNAMICTYPE_MAPENTRY, ],
  enum_types=[
    _DYNAMICTYPE_TYPEFLAG,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1260,
  serialized_end=1665,
)

_FEATURE.fields_by_name['feature_list_field'].message_type = _FEATURELIST
_FEATURE.fields_by_name['feature_map_field'].message_type = _FEATUREMAP
_FEATURE.fields_by_name['file_field'].message_type = _FILECONTENT
_FEATURE.oneofs_by_name['kind'].fields.append(
  _FEATURE.fields_by_name['string_field'])
_FEATURE.fields_by_name['string_field'].containing_oneof = _FEATURE.oneofs_by_name['kind']
_FEATURE.oneofs_by_name['kind'].fields.append(
  _FEATURE.fields_by_name['bytes_field'])
_FEATURE.fields_by_name['bytes_field'].containing_oneof = _FEATURE.oneofs_by_name['kind']
_FEATURE.oneofs_by_name['kind'].fields.append(
  _FEATURE.fields_by_name['float64_field'])
_FEATURE.fields_by_name['float64_field'].containing_oneof = _FEATURE.oneofs_by_name['kind']
_FEATURE.oneofs_by_name['kind'].fields.append(
  _FEATURE.fields_by_name['int64_field'])
_FEATURE.fields_by_name['int64_field'].containing_oneof = _FEATURE.oneofs_by_name['kind']
_FEATURE.oneofs_by_name['kind'].fields.append(
  _FEATURE.fields_by_name['feature_list_field'])
_FEATURE.fields_by_name['feature_list_field'].containing_oneof = _FEATURE.oneofs_by_name['kind']
_FEATURE.oneofs_by_name['kind'].fields.append(
  _FEATURE.fields_by_name['feature_map_field'])
_FEATURE.fields_by_name['feature_map_field'].containing_oneof = _FEATURE.oneofs_by_name['kind']
_FEATURE.oneofs_by_name['kind'].fields.append(
  _FEATURE.fields_by_name['file_field'])
_FEATURE.fields_by_name['file_field'].containing_oneof = _FEATURE.oneofs_by_name['kind']
_FILECONTENT.fields_by_name['type'].enum_type = _FILECONTENT_FILETYPE
_FILECONTENT_FILETYPE.containing_type = _FILECONTENT
_FEATUREMAP_MAPENTRY.fields_by_name['value'].message_type = _FEATURE
_FEATUREMAP_MAPENTRY.containing_type = _FEATUREMAP
_FEATUREMAP.fields_by_name['map'].message_type = _FEATUREMAP_MAPENTRY
_FEATURELIST.fields_by_name['list'].message_type = _FEATURE
_META.fields_by_name['record_type'].message_type = _RECORDTYPE
_RECORDTYPE_PROPERTIESENTRY.fields_by_name['value'].message_type = _RECORDTYPE
_RECORDTYPE_PROPERTIESENTRY.containing_type = _RECORDTYPE
_RECORDTYPE.fields_by_name['basicType'].enum_type = _RECORDTYPE_BASICTYPE
_RECORDTYPE.fields_by_name['properties'].message_type = _RECORDTYPE_PROPERTIESENTRY
_RECORDTYPE.fields_by_name['item'].message_type = _RECORDTYPE
_RECORDTYPE_BASICTYPE.containing_type = _RECORDTYPE
_PROPERTY_MAPENTRY.fields_by_name['value'].message_type = _DYNAMICTYPE
_PROPERTY_MAPENTRY.containing_type = _PROPERTY
_PROPERTY.fields_by_name['map'].message_type = _PROPERTY_MAPENTRY
_DYNAMICTYPE_MAPENTRY.fields_by_name['value'].message_type = _DYNAMICTYPE
_DYNAMICTYPE_MAPENTRY.containing_type = _DYNAMICTYPE
_DYNAMICTYPE.fields_by_name['flag'].enum_type = _DYNAMICTYPE_TYPEFLAG
_DYNAMICTYPE.fields_by_name['list'].message_type = _DYNAMICTYPE
_DYNAMICTYPE.fields_by_name['map'].message_type = _DYNAMICTYPE_MAPENTRY
_DYNAMICTYPE_TYPEFLAG.containing_type = _DYNAMICTYPE
DESCRIPTOR.message_types_by_name['Feature'] = _FEATURE
DESCRIPTOR.message_types_by_name['FileContent'] = _FILECONTENT
DESCRIPTOR.message_types_by_name['FeatureMap'] = _FEATUREMAP
DESCRIPTOR.message_types_by_name['FeatureList'] = _FEATURELIST
DESCRIPTOR.message_types_by_name['Index'] = _INDEX
DESCRIPTOR.message_types_by_name['Meta'] = _META
DESCRIPTOR.message_types_by_name['RecordType'] = _RECORDTYPE
DESCRIPTOR.message_types_by_name['Property'] = _PROPERTY
DESCRIPTOR.message_types_by_name['DynamicType'] = _DYNAMICTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Feature = _reflection.GeneratedProtocolMessageType('Feature', (_message.Message,), dict(
  DESCRIPTOR = _FEATURE,
  __module__ = 'define_pb2'
  # @@protoc_insertion_point(class_scope:dataset_proto.Feature)
  ))
_sym_db.RegisterMessage(Feature)

FileContent = _reflection.GeneratedProtocolMessageType('FileContent', (_message.Message,), dict(
  DESCRIPTOR = _FILECONTENT,
  __module__ = 'define_pb2'
  # @@protoc_insertion_point(class_scope:dataset_proto.FileContent)
  ))
_sym_db.RegisterMessage(FileContent)

FeatureMap = _reflection.GeneratedProtocolMessageType('FeatureMap', (_message.Message,), dict(

  MapEntry = _reflection.GeneratedProtocolMessageType('MapEntry', (_message.Message,), dict(
    DESCRIPTOR = _FEATUREMAP_MAPENTRY,
    __module__ = 'define_pb2'
    # @@protoc_insertion_point(class_scope:dataset_proto.FeatureMap.MapEntry)
    ))
  ,
  DESCRIPTOR = _FEATUREMAP,
  __module__ = 'define_pb2'
  # @@protoc_insertion_point(class_scope:dataset_proto.FeatureMap)
  ))
_sym_db.RegisterMessage(FeatureMap)
_sym_db.RegisterMessage(FeatureMap.MapEntry)

FeatureList = _reflection.GeneratedProtocolMessageType('FeatureList', (_message.Message,), dict(
  DESCRIPTOR = _FEATURELIST,
  __module__ = 'define_pb2'
  # @@protoc_insertion_point(class_scope:dataset_proto.FeatureList)
  ))
_sym_db.RegisterMessage(FeatureList)

Index = _reflection.GeneratedProtocolMessageType('Index', (_message.Message,), dict(
  DESCRIPTOR = _INDEX,
  __module__ = 'define_pb2'
  # @@protoc_insertion_point(class_scope:dataset_proto.Index)
  ))
_sym_db.RegisterMessage(Index)

Meta = _reflection.GeneratedProtocolMessageType('Meta', (_message.Message,), dict(
  DESCRIPTOR = _META,
  __module__ = 'define_pb2'
  # @@protoc_insertion_point(class_scope:dataset_proto.Meta)
  ))
_sym_db.RegisterMessage(Meta)

RecordType = _reflection.GeneratedProtocolMessageType('RecordType', (_message.Message,), dict(

  PropertiesEntry = _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), dict(
    DESCRIPTOR = _RECORDTYPE_PROPERTIESENTRY,
    __module__ = 'define_pb2'
    # @@protoc_insertion_point(class_scope:dataset_proto.RecordType.PropertiesEntry)
    ))
  ,
  DESCRIPTOR = _RECORDTYPE,
  __module__ = 'define_pb2'
  # @@protoc_insertion_point(class_scope:dataset_proto.RecordType)
  ))
_sym_db.RegisterMessage(RecordType)
_sym_db.RegisterMessage(RecordType.PropertiesEntry)

Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), dict(

  MapEntry = _reflection.GeneratedProtocolMessageType('MapEntry', (_message.Message,), dict(
    DESCRIPTOR = _PROPERTY_MAPENTRY,
    __module__ = 'define_pb2'
    # @@protoc_insertion_point(class_scope:dataset_proto.Property.MapEntry)
    ))
  ,
  DESCRIPTOR = _PROPERTY,
  __module__ = 'define_pb2'
  # @@protoc_insertion_point(class_scope:dataset_proto.Property)
  ))
_sym_db.RegisterMessage(Property)
_sym_db.RegisterMessage(Property.MapEntry)

DynamicType = _reflection.GeneratedProtocolMessageType('DynamicType', (_message.Message,), dict(

  MapEntry = _reflection.GeneratedProtocolMessageType('MapEntry', (_message.Message,), dict(
    DESCRIPTOR = _DYNAMICTYPE_MAPENTRY,
    __module__ = 'define_pb2'
    # @@protoc_insertion_point(class_scope:dataset_proto.DynamicType.MapEntry)
    ))
  ,
  DESCRIPTOR = _DYNAMICTYPE,
  __module__ = 'define_pb2'
  # @@protoc_insertion_point(class_scope:dataset_proto.DynamicType)
  ))
_sym_db.RegisterMessage(DynamicType)
_sym_db.RegisterMessage(DynamicType.MapEntry)


_FEATUREMAP_MAPENTRY._options = None
_RECORDTYPE_PROPERTIESENTRY._options = None
_PROPERTY_MAPENTRY._options = None
_DYNAMICTYPE_MAPENTRY._options = None
# @@protoc_insertion_point(module_scope)

